import os
import tempfile
import zipfile
from typing import Iterable

from abeja.exceptions import InvalidPathException


def extract_zipfile(content: bytes, path: str=None):
    """extract zipfile

    :param filename:
    :param path: a different directory to extract to.
    :return:
    :raises: PermissionError
             ValueError
             IOError
    """
    with tempfile.NamedTemporaryFile() as tf:
        tf.write(content)
        tf.seek(0)
        with zipfile.ZipFile(tf.name) as zf:
            zf.extractall(path=path)


def generate_path_iter(path: str, **kwargs) -> Iterable[str]:
    if os.path.isfile(path):
        yield path
    elif os.path.isdir(path):
        for root, _, file_paths in os.walk(path):
            for file_path in file_paths:
                yield os.path.join(root, file_path)
    else:
        raise InvalidPathException(path)
