# -*- coding: utf-8 -*-
import os
from abeja.datasets.dataset import Datasets
from abeja.datasets.api.client import APIClient


class Client:
    """A high-level client for Dataset API

    .. code-block:: python

       from abeja.datasets import Client

       client = Client()
    """

    def __init__(self, organization_id=None, credential=None):
        self.api = APIClient(credential=credential)
        self.organization_id = organization_id or os.environ.get('ABEJA_ORGANIZATION_ID')

    def get_dataset(self, dataset_id):
        """Get dataset for specific dataset_id

        Request syntax:
            .. code-block:: python

                response = client.get_dataset(dataset_id='1410805969256')

        Params:
            - **dataset_id** (str): dataset id

        Return type:
            dict

        Returns:
            Return syntax:
                .. code-block:: python

                    {
                        "created_at": "2018-04-10T07:49:30.514794",
                        "dataset_id": "1410805969256",
                        "name": "test-dataset",
                        "organization_id": "1102940376065",
                        "props": {
                            "attributes": [
                                {
                                    "categories": [
                                        {
                                            "id": 1,
                                            "name": "犬"
                                        },
                                        {
                                            "id": 2,
                                            "name": "猫"
                                        },
                                        {
                                            "id": 3,
                                            "name": "その他"
                                        }
                                    ],
                                    "id": 0,
                                    "name": "cats_dogs"
                                }
                            ]
                        },
                        "type": "detection",
                        "updated_at": "2018-04-10T07:49:30.514794"
                    }

        """
        datasets = Datasets(self.api, self.organization_id)
        return datasets.get(dataset_id)

    @property
    def datasets(self):
        """Get datasets object

        Request syntax:
            .. code-block:: python

                datasets = client.datasets()

        Returns:
            :meth:`Datasets <abeja.datasets.dataset.Datasets>`

        """
        return Datasets(self.api, self.organization_id)
